package model

import (
	"context"
	"fmt"
	"github.com/zeromicro/go-zero/core/stores/sqlc"
	"github.com/zeromicro/go-zero/core/stores/sqlx"
)

var _ DcWorkingValveModel = (*customDcWorkingValveModel)(nil)

type (
	// DcWorkingValveModel is an interface to be customized, add more methods here,
	// and implement the added methods in customDcWorkingValveModel.
	DcWorkingValveModel interface {
		dcWorkingValveModel
		FindOneByCode(ctx context.Context, projectId int64, deviceCode string) (*DcWorkingValve, error)
	}

	customDcWorkingValveModel struct {
		*defaultDcWorkingValveModel
	}
)

// NewDcWorkingValveModel returns a model for the database table.
func NewDcWorkingValveModel(conn sqlx.SqlConn) DcWorkingValveModel {
	return &customDcWorkingValveModel{
		defaultDcWorkingValveModel: newDcWorkingValveModel(conn),
	}
}
func (m *defaultDcWorkingValveModel) FindOneByCode(ctx context.Context, projectId int64, deviceCode string) (*DcWorkingValve, error) {
	var resp DcWorkingValve
	query := fmt.Sprintf("select %s from %s where `project_id` = ? and `device_code` = ? order by c_time desc limit 1", dcWorkingValveRows, m.table)
	err := m.conn.QueryRowCtx(ctx, &resp, query, projectId, deviceCode)
	switch err {
	case nil:
		return &resp, nil
	case sqlc.ErrNotFound:
		return nil, ErrNotFound
	default:
		return nil, err
	}
}
